==> guacamole-auth-openid-1.0.0.tar.gz: openid.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * Config block which registers openid-specific field types.
 */
angular.module('guacOpenID').config(['formServiceProvider',
        function guacOpenIDConfig(formServiceProvider) {

    // Define field for token from OpenID service
    formServiceProvider.registerFieldType("GUAC_OPENID_TOKEN", {
        templateUrl : 'app/ext/guac-openid/templates/openidTokenField.html',
        controller  : 'guacOpenIDController',
        module      : 'guacOpenID'
    });

}]);

/**
 * Config block which augments the existing routing, providing special handling
 * for the "id_token=" fragments provided by OpenID Connect.
 */
angular.module('index').config(['$routeProvider',
        function indexRouteConfig($routeProvider) {

    // Transform "/#/id_token=..." to "/#/?id_token=..."
    $routeProvider.when('/id_token=:response', {

        template   : '',
        controller : ['$location', function reroute($location) {
            var params = $location.path().substring(1);
            $location.url('/');
            $location.search(params);
        }]

    });

}]);
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * Controller for the "GUAC_OPENID_TOKEN" field which simply redirects the user
 * immediately to the authorization URI.
 */
angular.module('guacOpenID').controller('guacOpenIDController', ['$scope',
    function guacOpenIDController($scope) {

    // Redirect to authorization URI
    window.location = $scope.field.authorizationURI;

}]);
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * Module which provides handling for OpenID authentication.
 */
angular.module('guacOpenID', [
    'form'
]);

// Ensure the OpenID module is loaded along with the rest of the app
angular.module('index').requires.push('guacOpenID');
angular.module('templates-main', ['app/ext/guac-openid/templates/openidTokenField.html']);

angular.module('app/ext/guac-openid/templates/openidTokenField.html', []).run(['$templateCache', function($templateCache) {
	$templateCache.put('app/ext/guac-openid/templates/openidTokenField.html',
	"<div class=\"openid-token-field-container\">\n" +
	"    <div class=\"openid-token-field\">\n" +
	"        <p>{{ 'LOGIN.INFO_REDIRECT_PENDING' | translate }}</p>\n" +
	"    </div>\n" +
	"</div>");
}]);

==> guacamole-auth-openid-1.3.0.tar.gz: openid.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * Before AngularJS routing takes effect, reformat the URL fragment
 * from the format used by OpenID Connect ("#param1=value1&param2=value2&...")
 * to the format used by AngularJS ("#/?param1=value1&param2=value2&...") such
 * that the client side of Guacamole's authentication system will automatically
 * forward the "id_token" value for server-side validation.
 * 
 * Note that not all OpenID identity providers will include the "id_token"
 * parameter in the first position; it may occur after several other parameters
 * within the fragment.
 */

(function guacOpenIDTransformToken() {
    if (/^#(?![?\/])(.*&)?id_token=/.test(location.hash))
        location.hash = '/?' + location.hash.substring(1);
})();
